@@ -36,12 +36,18 @@
 #include <wx/bitmap.h>
 #include <wx/busyinfo.h>
 #include <wx/filesys.h>
-#include <wx/fontenum.h>
 #include <wx/fs_mem.h>
 #include <wx/imaglist.h>
 #include <wx/mimetype.h>
 #include <wx/statbox.h>
 #include <wx/utils.h>
+#include <wx/version.h>
+
+#if wxCHECK_VERSION(3, 1, 6)
+#define ARTPROV_GETTOOLBARBITMAP wxArtProvider::GetBitmapBundle
+#else
+#define ARTPROV_GETTOOLBARBITMAP wxArtProvider::GetBitmap
+#endif
 
 #define OPEN_HELP _("Open a CHM book.")
 #define FONTS_HELP _("Change fonts.")
@@ -193,28 +199,11 @@ void CHMFrame::OnOpen(wxCommandEvent&)
     LoadCHM(selection);
 }
 
-std::unique_ptr<wxArrayString> CHMFrame::SortedFontFaceNames(bool fixed) const
-{
-    wxFontEnumerator enu;
-    enu.EnumerateFacenames(wxFONTENCODING_SYSTEM, fixed);
-
-    auto fonts = std::make_unique<wxArrayString>(enu.GetFacenames());
-    fonts->Sort();
-
-    return fonts;
-}
-
 void CHMFrame::OnChangeFonts(wxCommandEvent&)
 {
     wxLogNull wln;
 
-    if (!_normalFonts)
-        _normalFonts = SortedFontFaceNames();
-
-    if (!_fixedFonts)
-        _fixedFonts = SortedFontFaceNames(true);
-
-    CHMFontDialog cfd(this, *_normalFonts, *_fixedFonts, _normalFont, _fixedFont, _nbhtml->FontSize());
+    CHMFontDialog cfd(this, _normalFont, _fixedFont, _nbhtml->FontSize());
 
     if (cfd.ShowModal() == wxID_OK) {
         wxBusyCursor bc;
@@ -390,7 +379,7 @@ void CHMFrame::OnRemoveBookmark(wxCommandEvent&)
         _cb->SetSelection(0);
         _bookmarkSel = true;
     } else
-        _cb->ChangeValue(wxEmptyString);
+        _cb->Clear();
 }
 
 void CHMFrame::OnBookmarkSel(wxCommandEvent& event)
@@ -741,7 +730,6 @@ wxPanel* CHMFrame::CreateContentsPanel()
 void CHMFrame::LoadBookmarks()
 {
     _cb->Clear();
-    _cb->ChangeValue(wxEmptyString);
 
     auto chmf = CHMInputStream::GetCache();
 
@@ -851,27 +839,26 @@ namespace {
 
 bool CHMFrame::InitToolBar(wxToolBar* toolbar)
 {
-    toolbar->AddTool(ID_Open, _("Open .."), wxArtProvider::GetBitmapBundle(wxART_FILE_OPEN, wxART_TOOLBAR), OPEN_HELP);
-    toolbar->AddTool(ID_Print, _("Print .."), wxArtProvider::GetBitmapBundle(wxART_PRINT, wxART_TOOLBAR), PRINT_HELP);
+    toolbar->AddTool(ID_Open, _("Open .."), ARTPROV_GETTOOLBARBITMAP(wxART_FILE_OPEN, wxART_TOOLBAR), OPEN_HELP);
+    toolbar->AddTool(ID_Print, _("Print .."), ARTPROV_GETTOOLBARBITMAP(wxART_PRINT, wxART_TOOLBAR), PRINT_HELP);
 
 #ifdef __WXGTK__
-    toolbar->AddTool(ID_Fonts, _("Fonts .."), wxArtProvider::GetBitmapBundle("gtk-select-font", wxART_TOOLBAR),
-                     FONTS_HELP);
-    toolbar->AddCheckTool(ID_Contents, _("Contents"), wxArtProvider::GetBitmapBundle("gtk-index", wxART_TOOLBAR),
-                          wxArtProvider::GetBitmapBundle("gtk-index", wxART_TOOLBAR), CONTENTS_HELP);
+    toolbar->AddTool(ID_Fonts, _("Fonts .."), ARTPROV_GETTOOLBARBITMAP("gtk-select-font", wxART_TOOLBAR), FONTS_HELP);
+    toolbar->AddCheckTool(ID_Contents, _("Contents"), ARTPROV_GETTOOLBARBITMAP("gtk-index", wxART_TOOLBAR),
+                          ARTPROV_GETTOOLBARBITMAP("gtk-index", wxART_TOOLBAR), CONTENTS_HELP);
 #else
     toolbar->AddTool(ID_Fonts, _("Fonts .."), wxBitmap(htmoptns_xpm), FONTS_HELP);
     toolbar->AddCheckTool(ID_Contents, _("Contents"), wxBitmap(htmsidep_xpm), wxBitmap(htmsidep_xpm), CONTENTS_HELP);
 #endif
 
     toolbar->AddSeparator();
-    toolbar->AddTool(ID_CopySelection, _("Copy"), wxArtProvider::GetBitmapBundle(wxART_COPY, wxART_TOOLBAR), COPY_HELP);
-    toolbar->AddTool(ID_FindInPage, _("Find"), wxArtProvider::GetBitmapBundle(wxART_FIND, wxART_TOOLBAR), FIND_HELP);
+    toolbar->AddTool(ID_CopySelection, _("Copy"), ARTPROV_GETTOOLBARBITMAP(wxART_COPY, wxART_TOOLBAR), COPY_HELP);
+    toolbar->AddTool(ID_FindInPage, _("Find"), ARTPROV_GETTOOLBARBITMAP(wxART_FIND, wxART_TOOLBAR), FIND_HELP);
 
     toolbar->AddSeparator();
 
 #ifdef __WXGTK__
-    toolbar->AddTool(ID_FullScreen, _("Fullscreen"), wxArtProvider::GetBitmapBundle("gtk-fullscreen", wxART_TOOLBAR),
+    toolbar->AddTool(ID_FullScreen, _("Fullscreen"), ARTPROV_GETTOOLBARBITMAP("gtk-fullscreen", wxART_TOOLBAR),
                      FULLSCREEN_HELP);
 #else
     toolbar->AddTool(ID_FullScreen, _("Fullscreen"), wxBitmap(fullscreen_xpm), FULLSCREEN_HELP);
@@ -879,16 +866,15 @@ bool CHMFrame::InitToolBar(wxToolBar* toolbar)
 
     toolbar->AddSeparator();
 
-    toolbar->AddTool(ID_Back, _("Back"), wxArtProvider::GetBitmapBundle(wxART_GO_BACK, wxART_TOOLBAR), BACK_HELP);
-    toolbar->AddTool(ID_Forward, _("Forward"), wxArtProvider::GetBitmapBundle(wxART_GO_FORWARD, wxART_TOOLBAR),
-                     FORWARD_HELP);
-    toolbar->AddTool(ID_Home, _("Home"), wxArtProvider::GetBitmapBundle(wxART_GO_HOME, wxART_TOOLBAR), HOME_HELP);
+    toolbar->AddTool(ID_Back, _("Back"), ARTPROV_GETTOOLBARBITMAP(wxART_GO_BACK, wxART_TOOLBAR), BACK_HELP);
+    toolbar->AddTool(ID_Forward, _("Forward"), ARTPROV_GETTOOLBARBITMAP(wxART_GO_FORWARD, wxART_TOOLBAR), FORWARD_HELP);
+    toolbar->AddTool(ID_Home, _("Home"), ARTPROV_GETTOOLBARBITMAP(wxART_GO_HOME, wxART_TOOLBAR), HOME_HELP);
     toolbar->AddSeparator();
 
 #ifdef __WXGTK__
-    toolbar->AddTool(ID_About, _("About"), wxArtProvider::GetBitmapBundle("gtk-about", wxART_TOOLBAR), ABOUT_HELP);
+    toolbar->AddTool(ID_About, _("About"), ARTPROV_GETTOOLBARBITMAP("gtk-about", wxART_TOOLBAR), ABOUT_HELP);
 #else
-    toolbar->AddTool(ID_About, _("About"), wxArtProvider::GetBitmapBundle(wxART_HELP, wxART_TOOLBAR), ABOUT_HELP);
+    toolbar->AddTool(ID_About, _("About"), ARTPROV_GETTOOLBARBITMAP(wxART_HELP, wxART_TOOLBAR), ABOUT_HELP);
 #endif
 
     toolbar->Realize();
